"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.response = void 0;

var _path = _interopRequireDefault(require("path"));

var _mkdirp = require("mkdirp");

var _fs = _interopRequireDefault(require("fs"));

var _fsExtra = require("fs-extra");

var _lodash = require("lodash");

var _getEnvVar = _interopRequireDefault(require("get-env-var"));

var _paths = require("../paths");

var config = _interopRequireWildcard(require("../config"));

const alreadyAdded = 'alreadyAdded';
const success = 'success';
const fail = 'fail';
const unsupported = 'unsupported';
const response = {
  alreadyAdded,
  success,
  fail,
  unsupported
};
exports.response = response;

var _default = (file, filePath) => {
  (0, _mkdirp.sync)(_paths.appDir);
  let srcPath = null;
  const homePath = (0, _getEnvVar.default)('HOME', '');

  switch (file) {
    case 'config':
      return unsupported;

    case 'bash_profile':
      srcPath = (0, _lodash.defaultTo)(filePath, _path.default.join(homePath, '.bash_profile'));
      break;

    case 'bashrc':
      srcPath = (0, _lodash.defaultTo)(filePath, _path.default.join(homePath, '.bashrc'));
      break;

    case 'vimrc':
      srcPath = (0, _lodash.defaultTo)(filePath, _path.default.join(homePath, '.vimrc'));
      break;

    case 'gitconfig':
      srcPath = (0, _lodash.defaultTo)(filePath, _path.default.join(homePath, '.gitconfig'));
      break;

    case 'zshrc':
      srcPath = (0, _lodash.defaultTo)(filePath, _path.default.join(homePath, '.zshrc'));
      break;

    default:
      if (!filePath) return unsupported;
      srcPath = filePath;
  }

  if (!srcPath) return fail;
  (0, _fsExtra.ensureFileSync)(srcPath);

  if (_fs.default.lstatSync(srcPath).isSymbolicLink()) {
    return alreadyAdded;
  }

  const addedFilePath = _path.default.join(_paths.appDir, file); // replace original file with symlink


  if (config.getConfig('file.createBackup')) (0, _fsExtra.copySync)(srcPath, `${srcPath}.bak`);
  (0, _fsExtra.copySync)(srcPath, addedFilePath);
  (0, _fsExtra.removeSync)(srcPath);
  (0, _fsExtra.ensureSymlinkSync)(addedFilePath, srcPath); // add config

  config.setConfig(`path.${file}`, srcPath);
  return success;
};

exports.default = _default;