"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _leftPad = _interopRequireDefault(require("left-pad"));

var _co = _interopRequireDefault(require("co"));

var _coPrompt = _interopRequireDefault(require("co-prompt"));

var _chalk = _interopRequireDefault(require("chalk"));

var _jsonStableStringify = _interopRequireDefault(require("json-stable-stringify"));

var _config = require("../config");

var _upload = require("../upload");

var _print = _interopRequireDefault(require("./print"));

var _github = require("../github/github");

var _gist = require("../github/gist");

var _default = () => {
  const gist = (0, _config.getConfig)('repository.gist');
  const getGistAndUpload = gist && gist.length ? (0, _gist.get)(gist).then(r => r && r.data && r.data.files ? executeUpload() : Promise.reject({
    code: 404
  })) : Promise.reject({
    code: 404
  });
  getGistAndUpload.catch(e => {
    // Gist id is not set or invalid gist id
    if (e && e.code === 404) {
      (0, _co.default)(function* () {
        _print.default.error('Invalid gist', 'Gist id is not set or invalid.');

        const gistId = yield (0, _coPrompt.default)(_chalk.default.green('Gist id(Empty to create a new gist): '));
        let createOrGet;

        if (gistId && gistId.length) {
          createOrGet = (0, _gist.get)(gistId).then(() => (0, _config.setConfig)('repository.gist', gistId));
        } else {
          const response = yield (0, _coPrompt.default)(_chalk.default.green('Do you want to make it public?(y/n)'));
          const publicity = ['y', 'yes'].indexOf(response.toLowerCase()) !== -1;

          _print.default.info(`Gist will be created in ${_chalk.default.bold.white(publicity ? 'pubic' : 'private')}.`);

          createOrGet = (0, _gist.create)({
            files: (0, _upload.getUploadingFiles)(),
            public: publicity
          });
        }

        createOrGet.then(() => (0, _config.setConfig)('repository.gist', gistId)).then(executeUpload).catch(({
          message
        }) => _print.default.error(`GIST ERROR`, message)).then(() => process.stdin.pause());
      });
    }
  });
};

exports.default = _default;

const executeUpload = () => (0, _upload.upload)().catch(err => new Promise((resolve, reject) => {
  if (err && err.code === 401) {
    (0, _co.default)(function* () {
      _print.default.error('Invalid token', 'Github Token is not valid.');

      const githubToken = yield (0, _coPrompt.default)(_chalk.default.green('Github Token: '));
      (0, _config.setConfig)('repository.githubToken', githubToken);
      resolve((0, _upload.upload)());
    });
  } else {
    reject(err);
  }
})).then(({
  uploaded,
  deleted
}) => {
  _print.default.info(`Success`);

  if (uploaded.length) {
    _print.default.info(_chalk.default.bold.blue('Uploaded files'));

    _print.default.info(uploaded.map(f => `  - ${f}`).join('\n'));
  }

  if (deleted.length) {
    _print.default.info(_chalk.default.bold.magenta('Deleted files'));

    _print.default.info(deleted.map(f => `  - ${f}`).join('\n'));
  }
});