"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.removeConfig = exports.setConfig = exports.getConfigs = exports.getConfig = void 0;

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var fs = _interopRequireWildcard(require("fs"));

var _os = _interopRequireDefault(require("os"));

var _fsExtra = require("fs-extra");

var _mkdirp = require("mkdirp");

var _rc = _interopRequireDefault(require("rc"));

var _jsonStableStringify = _interopRequireDefault(require("json-stable-stringify"));

var _lodash = require("lodash");

var _keys = require("./keys");

var _paths = require("../paths");

var _defaultConfig = _interopRequireDefault(require("./defaultConfig"));

const getConfig = key => {
  const config = getConfigs(key);
  return key ? config[key] : config;
};

exports.getConfig = getConfig;

const getConfigs = (...keys) => {
  const rcFile = _os.default.type().toLowerCase().indexOf('windows') !== -1 ? fs.existsSync(_paths.configFile) ? (0, _fsExtra.readJsonSync)(_paths.configFile) : {} : (0, _rc.default)(_paths.appName);
  const config = (0, _lodash.omit)((0, _objectSpread2.default)({}, _defaultConfig.default, rcFile), ['_', 'config', 'configs']);
  keys = keys.filter(k => !!k);
  return keys.length ? (0, _lodash.pick)(config, keys) : config;
};

exports.getConfigs = getConfigs;

const setConfig = (key, value) => {
  (0, _mkdirp.sync)(_paths.appDir);
  const existingConfig = fs.existsSync(_paths.configFile) ? JSON.parse(fs.readFileSync(_paths.configFile)) : {}; // Convert

  value = (v => {
    if (!isNaN(+v)) return +v;

    switch (v) {
      case 'true':
        return true;

      case 'false':
        return false;
    }

    return v;
  })(value);

  if (!(0, _keys.validate)(key, value)) throw new Error(`Invalid key value pair { '${key}' : ${value} }`, 'Validation Error');
  const newConfig = (0, _objectSpread2.default)({}, existingConfig, {
    [key]: value
  });
  fs.writeFileSync(_paths.configFile, (0, _jsonStableStringify.default)(newConfig, {
    space: '  '
  }));
  return newConfig;
};

exports.setConfig = setConfig;

const removeConfig = key => {
  (0, _mkdirp.sync)(_paths.appDir);
  const existingConfig = fs.existsSync(_paths.configFile) ? JSON.parse(fs.readFileSync(_paths.configFile)) : {};
  const newConfig = (0, _lodash.omit)(existingConfig, [key]);
  fs.writeFileSync(_paths.configFile, (0, _jsonStableStringify.default)(newConfig, {
    space: '  '
  }));
  return newConfig;
};

exports.removeConfig = removeConfig;