"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _fs = _interopRequireDefault(require("fs"));

var fsExtra = _interopRequireWildcard(require("fs-extra"));

var _path = _interopRequireDefault(require("path"));

var _jsonStableStringify = _interopRequireDefault(require("json-stable-stringify"));

var _paths = require("../paths");

var _config = require("../config");

var gist = _interopRequireWildcard(require("../github/gist"));

const linkFiles = async () => {
  const config = (0, _config.getConfig)();
  return await Promise.all(Object.keys(config).filter(key => key.startsWith('path.')).map(async key => {
    const file = key.substr(5);
    const filePath = config[key];

    if (_fs.default.existsSync(filePath) && !_fs.default.statSync(filePath).isSymbolicLink()) {
      fsExtra.copyFileSync(filePath, `${filePath}.bak`, {
        overwrite: true
      });
      fsExtra.removeSync(filePath);
    }

    fsExtra.ensureSymlinkSync(_path.default.join(_paths.appDir, file), filePath);
    return {
      name: file,
      path: filePath
    };
  }));
};

var _default = async () => {
  const repoType = (0, _config.getConfig)('repository.type');
  if (!repoType) throw new Error(`Specify the repository type using 'icbm config set <key> <value>'`);

  switch (repoType) {
    case 'gist':
      const res = await gist.get((0, _config.getConfig)('repository.gist'));
      const files = res.data.files;
      const fileList = Object.keys(files);

      for (let i = 0, len = fileList.length; i < len; i++) {
        const file = fileList[i];
        const content = files[file].content;

        _fs.default.writeFileSync(_path.default.join(_paths.appDir, file), content === 'EMPTY_CONTENT' ? '' : content, {
          encoding: 'utf8'
        });
      }

      const linkedFiles = await linkFiles();
      return linkedFiles;

    default:
      return Promise.reject({
        message: `${repoType} is not supported yet.`,
        id: 'Invalid repository type'
      });
  }
};

exports.default = _default;