"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.getUploadingFiles = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _jsonStableStringify = _interopRequireDefault(require("json-stable-stringify"));

var _lodash = require("lodash");

var _paths = require("../paths");

var _config = require("../config");

var gist = _interopRequireWildcard(require("../github/gist"));

var _version = _interopRequireDefault(require("../version"));

const getUploadingFiles = () => {
  const files = _fs.default.readdirSync(_paths.appDir).reduce((filesObject, file) => {
    const content = _fs.default.readFileSync(_path.default.join(_paths.appDir, file), 'utf8');

    filesObject[file] = {
      content: content.trim().length || content.trim() === '\n' ? content : 'EMPTY_CONTENT'
    };
    return filesObject;
  }, {});

  files.syncInfo = {
    content: (0, _jsonStableStringify.default)({
      version: _version.default,
      lastUpdated: new Date().toISOString()
    }) + '\n'
  };
  return files;
};

exports.getUploadingFiles = getUploadingFiles;

var _default = () => {
  const repoType = (0, _config.getConfig)('repository.type');
  if (!repoType) throw new Error(`Specify the repository type using 'icbm config set repository.type <type>'`);

  switch (repoType) {
    case 'gist':
      const files = getUploadingFiles();
      return gist.get((0, _config.getConfig)('repository.gist')).then(res => {
        const deleted = Object.keys(res.data.files).filter(f => !(0, _lodash.has)(files, f));
        deleted.forEach(f => files[f] = null);
        return gist.edit(files).then(() => Promise.resolve({
          uploaded: (0, _lodash.without)(Object.keys(files), ...deleted),
          deleted
        }));
      });

    default:
      return Promise.reject({
        message: `${repoType} is not supported yet.`,
        id: 'Invalid repository type'
      });
  }
};

exports.default = _default;